PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/RL/Action.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures
Action.hpp File Reference
`#include "Defs.hpp"`
`#include "RL/Reward.hpp"`
`#include <string>`

Go to the source code of this file.

## Data Structures
class | Action
| NOTE: Actions always set the Agent's least recently used connction (getConnectionLRU()) which is somewhat ugly for actions affecting multiple connections - we should probably return a set of affected connections if we ever have actions that change more than one (other than clustering which doesn't really change anything). More...
struct | Action::Result